@@ -21,7 +21,8 @@ class _Properties(object):
         * host
 
     """
-    _do_not_duplicate = ('host', 'to_dict', 'to_honeybee', 'ToString')
+    _exclude = ('host', 'move', 'rotate_xy', 'reflect', 'scale', 'add_prefix',
+                'reset_to_default', 'to_dict', 'to_honeybee', 'ToString')
 
     def __init__(self, host):
         """Initialize properties."""
@@ -32,6 +33,97 @@ class _Properties(object):
         """Get the object hosting these properties."""
         return self._host
 
+    @property
+    def _extension_attributes(self):
+        return (atr for atr in dir(self) if not atr.startswith('_')
+                and atr not in self._exclude)
+
+    def move(self, moving_vec):
+        """Apply a move transform to extension attributes.
+
+        This is useful in cases where extension attributes possess geometric data
+        that should be moved alongside the host object.
+
+        Args:
+            moving_vec: A ladybug_geometry Vector3D with the direction and distance
+                to move the face.
+        """
+        for atr in self._extension_attributes:
+            var = getattr(self, atr)
+            if not hasattr(var, 'move'):
+                continue
+            try:
+                var.move(moving_vec)
+            except Exception as e:
+                import traceback
+                traceback.print_exc()
+                raise Exception('Failed to move {}: {}'.format(var, e))
+
+    def rotate_xy(self, angle, origin):
+        """Apply a rotatation in the XY plane to extension attributes.
+
+        This is useful in cases where extension attributes possess geometric data
+        that should be rotated alongside the host object.
+
+        Args:
+            angle: An angle in degrees.
+            origin: A ladybug_geometry Point3D for the origin around which the
+                object will be rotated.
+        """
+        for atr in self._extension_attributes:
+            var = getattr(self, atr)
+            if not hasattr(var, 'rotate_xy'):
+                continue
+            try:
+                var.rotate_xy(angle, origin)
+            except Exception as e:
+                import traceback
+                traceback.print_exc()
+                raise Exception('Failed to rotate {}: {}'.format(var, e))
+
+    def reflect(self, plane):
+        """Apply a reflection transform to extension attributes.
+
+        This is useful in cases where extension attributes possess geometric data
+        that should be reflected alongside the host object.
+
+        Args:
+            plane: A ladybug_geometry Plane across which the object will
+                be reflected.
+        """
+        for atr in self._extension_attributes:
+            var = getattr(self, atr)
+            if not hasattr(var, 'reflect'):
+                continue
+            try:
+                var.reflect(plane)
+            except Exception as e:
+                import traceback
+                traceback.print_exc()
+                raise Exception('Failed to reflect {}: {}'.format(var, e))
+
+    def scale(self, factor, origin=None):
+        """Apply a scale transform to extension attributes.
+
+        This is useful in cases where extension attributes possess geometric data
+        that should be scaled alongside the host object.
+
+        Args:
+            factor: A number representing how much the object should be scaled.
+            origin: A ladybug_geometry Point3D representing the origin from which
+                to scale. If None, it will be scaled from the World origin (0, 0, 0).
+        """
+        for atr in self._extension_attributes:
+            var = getattr(self, atr)
+            if not hasattr(var, 'scale'):
+                continue
+            try:
+                var.scale(factor, origin)
+            except Exception as e:
+                import traceback
+                traceback.print_exc()
+                raise Exception('Failed to scale {}: {}'.format(var, e))
+
     def _duplicate_extension_attr(self, original_properties):
         """Duplicate the attributes added by extensions.
 
@@ -45,10 +137,7 @@ class _Properties(object):
             original_properties: The properties object of the original core
                 object from which the duplicate was derived.
         """
-        attr = [atr for atr in dir(self)
-                if not atr.startswith('_') and atr not in self._do_not_duplicate]
-
-        for atr in attr:
+        for atr in self._extension_attributes:
             var = getattr(original_properties, atr)
             if not hasattr(var, 'duplicate'):
                 continue
@@ -75,10 +164,7 @@ class _Properties(object):
                 identifier. It is recommended that this prefix be short to avoid maxing
                 out the 100 allowable characters for honeybee identifiers.
         """
-        attr = [atr for atr in dir(self)
-                if not atr.startswith('_') and atr not in self._do_not_duplicate]
-
-        for atr in attr:
+        for atr in self._extension_attributes:
             var = getattr(self, atr)
             if not hasattr(var, 'add_prefix'):
                 continue
@@ -100,10 +186,7 @@ class _Properties(object):
             honeybee_properties: A honeybee-core Properties object to which the
                 dragonfly-core extension attributes will be added.
         """
-        attr = [atr for atr in dir(self)
-                if not atr.startswith('_') and atr not in self._do_not_duplicate]
-
-        for atr in attr:
+        for atr in self._extension_attributes:
             var = getattr(self, atr)
             if not hasattr(var, 'to_honeybee'):
                 continue
@@ -138,12 +221,7 @@ class _Properties(object):
                 available in properties to_dict. By default all the keys will be
                 included. To exclude all the keys from extensions use an empty list.
         """
-        if include is not None:
-            attr = include
-        else:
-            attr = [atr for atr in dir(self)
-                    if not atr.startswith('_') and atr not in self._do_not_duplicate]
-
+        attr = include if include is not None else self._extension_attributes
         for atr in attr:
             var = getattr(self, atr)
             if not hasattr(var, 'to_dict'):
@@ -170,10 +248,7 @@ class _Properties(object):
                 attributes from the dictionary and assign them to the object on which
                 this method is called.
         """
-        attr = [atr for atr in dir(self)
-                if not atr.startswith('_') and atr not in self._do_not_duplicate]
-
-        for atr in attr:
+        for atr in self._extension_attributes:
             var = getattr(self, atr)
             if not hasattr(var, 'from_dict'):
                 continue
@@ -212,15 +287,8 @@ class ModelProperties(_Properties):
             include: A list of keys to be included in dictionary.
                 If None all the available keys will be included.
         """
-        base = {
-            'type': 'ModelProperties'
-        }
-        if include is not None:
-            attr = include
-        else:
-            attr = [atr for atr in dir(self)
-                    if not atr.startswith('_') and atr != 'host']
-
+        base = {'type': 'ModelProperties'}
+        attr = include if include is not None else self._extension_attributes
         for atr in attr:
             var = getattr(self, atr)
             if not hasattr(var, 'to_dict'):
@@ -239,10 +307,7 @@ class ModelProperties(_Properties):
         Args:
             data: A dictionary representation of an entire dragonfly-core Model.
         """
-        attr = [atr for atr in dir(self)
-                if not atr.startswith('_') and atr not in self._do_not_duplicate]
-
-        for atr in attr:
+        for atr in self._extension_attributes:
             if atr not in data['properties'] or data['properties'][atr] is None:
                 continue
             var = getattr(self, atr)
